''' Resources (sub) package, used to connect URLs to views '''

from pyramid.security import Allow, Everyone, DENY_ALL

from .base import BaseResource
from .account import AccountResource


class RootResource(BaseResource):
    ''' The root resource for the application

    :param request:
        the current request object
    :type request:
        pyramid.request.Request
    '''

    #: name of the main navigation section for template highlighting
    nav_section = 'root'

    #: dict to match the next url path segment
    nodes = {
        'account': AccountResource
        }

    def __init__(self, request):
        ''' Create the root resource '''
        self.__name__ = None
        self.__parent__ = None
        self.request = request

    def __acl__(self):
        ''' access controll list for the resource '''
        return [(Allow, Everyone, 'view'), DENY_ALL]


def includeme(config):
    '''
    Initialize the resources for traversal in a Pyramid app.

    Activate this setup using ``config.include('ordr2.resources')``.

    '''
    config.set_root_factory(RootResource)
