import colander
import deform

from ordr2.models import Role

from . import CSRFSchema
from .helpers import (
    deferred_unique_email_validator,
    deferred_unique_username_validator,
    deferred_password_validator
    )


# schema for user registration

class RegistrationSchema(CSRFSchema):
    ''' new user registration '''

    username = colander.SchemaNode(
        colander.String(),
        widget=deform.widget.TextInputWidget(readonly=True),
        description='automagically generated for you',
        validator=deferred_unique_username_validator,
        )
    first_name = colander.SchemaNode(
        colander.String()
        )
    last_name = colander.SchemaNode(
        colander.String()
        )
    email = colander.SchemaNode(
        colander.String(),
        validator=deferred_unique_email_validator
        )
    password = colander.SchemaNode(
        colander.String(),
        widget=deform.widget.CheckedPasswordWidget()
        )

    @classmethod
    def as_form(cls, request, **override):
        settings = {
            'buttons': ('Create Account', 'Cancel'),
            'css_class': 'form registration'
            }
        settings.update(override)
        return super().as_form(request, **settings)


class ResetPasswordSchema(CSRFSchema):
    ''' reset a password '''

    password = colander.SchemaNode(
        colander.String(),
        widget=deform.widget.CheckedPasswordWidget()
        )

    @classmethod
    def as_form(cls, request, **override):
        settings = {
            'buttons': ('Reset Password', 'Cancel'),
            'css_class': 'form reset-password'
            }
        settings.update(override)
        return super().as_form(request, **settings)



class SettingsSectionGeneralSchema(colander.Schema):
    ''' Section 'General' for account settings schema '''

    username = colander.SchemaNode(
        colander.String(),
        widget=deform.widget.TextInputWidget(readonly=True),
        )
    first_name = colander.SchemaNode(
        colander.String()
        )
    last_name = colander.SchemaNode(
        colander.String()
        )
    email = colander.SchemaNode(
        colander.String(),
        validator=deferred_unique_email_validator
        )
    role = colander.SchemaNode(
        colander.String(),
        widget=deform.widget.TextInputWidget(readonly=True),
        )


class SettingsSectionChangePasswordSchema(colander.Schema):
    ''' Section 'Change Password' for account settings schema '''

    new_password = colander.SchemaNode(
        colander.String(),
        widget=deform.widget.CheckedPasswordWidget(),
        missing=''
        )


class SettingsSectionConfirmChangesSchema(colander.Schema):
    ''' Section 'ConfirmChanges' for account settings schema '''

    password = colander.SchemaNode(
        colander.String(),
        widget=deform.widget.PasswordWidget(),
        validator=deferred_password_validator,
        description='Enter your current password to confirm changes'
        )


class AccountSettingsSchema(CSRFSchema):
    ''' account settings schema '''

    general = SettingsSectionGeneralSchema()
    change_password = SettingsSectionChangePasswordSchema()
    confirm_changes = SettingsSectionConfirmChangesSchema()

    @classmethod
    def as_form(cls, request, **override):
        settings = {
            'buttons': ('Save Settings', 'Cancel'),
            'css_class': 'form account-settings'
            }
        settings.update(override)
        return super().as_form(request, **settings)
