''' Tests for ordr2.security '''

import pytest

from datetime import datetime
from pyramid.testing import DummyRequest
from pyramid_mailer import get_mailer

from . import app_config, get_user


def test_user_notification_init(app_config):
    ''' test creation of user notification events '''
    from ordr2.events import UserNotification

    user = get_user('user')
    notification = UserNotification('request', user, 'data')

    assert notification.request == 'request'
    assert notification.account == user
    assert notification.data == 'data'
    assert notification.send_to == user.email


def test_user_notification_init_different_send_to(app_config):
    ''' test creation of user notification events '''
    from ordr2.events import UserNotification

    user = get_user('user')
    notification = UserNotification(None, None, None, 'eric@example.com')

    assert notification.send_to == 'eric@example.com'


def test_notify_user(app_config):
    from ordr2.events import CompleteRegistration, notify_user
    from ordr2.models.account import Token

    request = DummyRequest()
    user = get_user('user')
    token = Token(expires=datetime.utcnow(), hash='some_hash')
    notification = CompleteRegistration(request, user, {'token': token})
    notify_user(notification)
    mailer = get_mailer(request.registry)
    last_mail = mailer.outbox[-1]

    assert 'Please verify your email address ' in last_mail.html
    assert 'http://example.com//some_hash' in last_mail.html
